==> CDMConnector_2.1.1.tar.gz: CDMConnector/R/reexports-omopgenerics.R <==
# Copyright 2025 DARWIN EU®
#
# This file is part of CDMConnector
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

#' @importFrom omopgenerics cohortCount
#' @export
omopgenerics::cohortCount

#' @importFrom omopgenerics settings
#' @export
omopgenerics::settings

#' @importFrom omopgenerics attrition
#' @export
omopgenerics::attrition

#' @importFrom omopgenerics newCohortTable
#' @export
omopgenerics::newCohortTable

#' @importFrom omopgenerics cdmDisconnect
#' @export
omopgenerics::cdmDisconnect

#' @importFrom omopgenerics insertTable
#' @export
omopgenerics::insertTable

#' @importFrom omopgenerics insertCdmTo
#' @export
omopgenerics::insertCdmTo

#' @importFrom omopgenerics dropTable
#' @export
omopgenerics::dropTable

#' @importFrom omopgenerics readSourceTable
#' @export
omopgenerics::readSourceTable

#' @importFrom omopgenerics dropSourceTable
#' @export
omopgenerics::dropSourceTable

#' @importFrom omopgenerics listSourceTables
#' @export
omopgenerics::listSourceTables

#' @importFrom omopgenerics bind
#' @export
omopgenerics::bind

#' @importFrom omopgenerics cdmVersion
#' @export
omopgenerics::cdmVersion

#' @importFrom omopgenerics cdmFromTables
#' @export
omopgenerics::cdmFromTables

#' @importFrom omopgenerics cohortCodelist
#' @export
omopgenerics::cohortCodelist

#' @importFrom omopgenerics cdmName
#' @export
omopgenerics::cdmName

#' @importFrom omopgenerics recordCohortAttrition
#' @export
omopgenerics::recordCohortAttrition

#' @importFrom omopgenerics uniqueTableName
#' @export
omopgenerics::uniqueTableName

#' @importFrom omopgenerics cdmSelect
#' @export
omopgenerics::cdmSelect

==> CDMConnector_2.3.0.tar.gz: CDMConnector/R/reexports-omopgenerics.R <==
# Copyright 2025 DARWIN EU®
#
# This file is part of CDMConnector
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

#' @importFrom omopgenerics cohortCount
#' @export
omopgenerics::cohortCount

#' @importFrom omopgenerics settings
#' @export
omopgenerics::settings

#' @importFrom omopgenerics attrition
#' @export
omopgenerics::attrition

#' @importFrom omopgenerics newCohortTable
#' @export
omopgenerics::newCohortTable

#' @importFrom omopgenerics cdmDisconnect
#' @export
omopgenerics::cdmDisconnect

#' @importFrom omopgenerics insertTable
#' @export
omopgenerics::insertTable

#' @importFrom omopgenerics insertCdmTo
#' @export
omopgenerics::insertCdmTo

#' @importFrom omopgenerics dropTable
#' @export
omopgenerics::dropTable

#' @importFrom omopgenerics readSourceTable
#' @export
omopgenerics::readSourceTable

#' @importFrom omopgenerics dropSourceTable
#' @export
omopgenerics::dropSourceTable

#' @importFrom omopgenerics listSourceTables
#' @export
omopgenerics::listSourceTables

#' @importFrom omopgenerics bind
#' @export
omopgenerics::bind

#' @importFrom omopgenerics cdmVersion
#' @export
omopgenerics::cdmVersion

#' @importFrom omopgenerics cdmFromTables
#' @export
omopgenerics::cdmFromTables

#' @importFrom omopgenerics cohortCodelist
#' @export
omopgenerics::cohortCodelist

#' @importFrom omopgenerics cdmName
#' @export
omopgenerics::cdmName

#' @importFrom omopgenerics recordCohortAttrition
#' @export
omopgenerics::recordCohortAttrition

#' @importFrom omopgenerics uniqueTableName
#' @export
omopgenerics::uniqueTableName

#' @importFrom omopgenerics cdmSelect
#' @export
omopgenerics::cdmSelect

#' @importFrom omopgenerics sourceType
#' @export
omopgenerics::sourceType

#' @importFrom omopgenerics cdmReference
#' @export
omopgenerics::cdmReference
